<!--
SPDX-FileCopyrightText: 2021 - 2023  StorPool <support@storpool.com>
SPDX-License-Identifier: BSD-2-Clause
-->

# API reference for stuff and stuff

## variant: the top-level functions and structures

::: sp_variant.variant

## defs: some additional definitions and substructures

::: sp_variant.defs
